#
# spec file for package libdispatch
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define reltag 5.6.3-RELEASE
Name:           libdispatch
Version:        5.6.3
Release:        2.3
Summary:        Apple's Grand Central Dispatch library
License:        Apache-2.0
Group:          Development/Languages/C and C++
URL:            https://github.com/apple/swift-corelibs-libdispatch
Source0:        https://github.com/apple/swift-corelibs-libdispatch/archive/swift-%{reltag}.tar.gz#/corelibs-libdispatch.tar.gz
Source1:        libdispatch-rpmlintrc
Patch0:         prevent_unused.patch
# set library versions
Patch2:         soversion.patch
BuildRequires:  chrpath
BuildRequires:  clang
BuildRequires:  cmake
BuildRequires:  libbsd-devel
BuildRequires:  libstdc++-devel
BuildRequires:  llvm-gold
BuildRequires:  ninja
# Disable i586 build for now
%ifarch i586
ExclusiveArch:  do_not_build
%endif

%description
Grand Central Dispatch (GCD or libdispatch) provides support for
concurrent code execution on multicore hardware.

%package -n libdispatch1_3
Summary:        Apple's Grand Central Dispatch library
Group:          System/Libraries
Obsoletes:      libdispatch < %{version}-%{release}
Provides:       libdispatch = %{version}-%{release}

%description -n libdispatch1_3
Grand Central Dispatch (GCD or libdispatch) provides support for
concurrent code execution on multicore hardware.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       libdispatch1_3 = %{version}-%{release}
# Wrong location for manpages in older version
Conflicts:      libdispatch < %{version}-%{release}
BuildArch:      noarch

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1 -n swift-corelibs-libdispatch-swift-%{reltag}

%build
export CC=clang
export CXX=clang++
# clang doesn't have 'auto'
# aarch64 specific flag
%ifarch aarch64 riscv64
export CFLAGS="%{optflags} -Wno-unused-command-line-argument"
%else
export CFLAGS="%{optflags}"
%endif
CFLAGS=${CFLAGS/-flto=auto/-flto}

%ifarch aarch64 riscv64
export CXXFLAGS="%{optflags} -Wno-unused-command-line-argument"
%else
export CXXFLAGS="%{optflags}"
%endif
CXXFLAGS=${CXXFLAGS/-flto=auto/-flto}
export LDFLAGS="-flto -Wl,--as-needed -Wl,--no-undefined -Wl,-z,now"

%define __builder ninja
%cmake \
    -DCMAKE_Fortran_FLAGS="$CXXFLAGS" \
    -DCMAKE_EXE_LINKER_FLAGS="$LDFLAGS" \
    -DCMAKE_MODULE_LINKER_FLAGS="-flto -Wl, --as-needed" \
    -DCMAKE_SHARED_LINKER_FLAGS="$LDFLAGS" \
    -DINSTALL_BLOCK_HEADERS_DIR:PATH=include/block .
ninja

%install
%cmake_install
chrpath --delete %{buildroot}%{_libdir}/libdispatch.so.1.3

%post   -n libdispatch1_3 -p /sbin/ldconfig
%postun -n libdispatch1_3 -p /sbin/ldconfig

%files -n libdispatch1_3
%license LICENSE
%{_libdir}/*.so*

%files devel
%dir %{_includedir}/block
%{_includedir}/block/*
%dir %{_includedir}/dispatch
%{_includedir}/dispatch/*
%dir %{_includedir}/os
%{_includedir}/os/*
%{_mandir}/man3/*

%changelog
* Thu Jul 13 2023 Andreas Schwab <schwab@suse.de>
- Disable unused-command-line-argument warning on riscv64
* Fri Oct 14 2022 Predrag Ivanović <predivan@mts.rs>
- Update to versio 5.6.3
  * No upstream provided changelog.
  * Add prevent_unused.patch to fix the build with clang > 13
    Prevent unused but set variable warning
    (https://github.com/apple/swift-corelibs-libdispatch/pull/764)
  * Resolve rpmlint "E: libdispatch-devel  no-binary" error by
  declaring libdispatch-devel as noarch.
* Sat Jul  2 2022 Predrag Ivanović <predivan@mts.rs>
- Update to version 5.6.2
  * No upstream provided changelog.
  * Drop 563.patch and 574.patch, merged upstream/no longer required.
  * Disable i586 arch build for now.
* Wed May 25 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint error "libdispatch.x86_64: E:
  shlib-policy-name-error SONAME: libBlocksRuntime.so.1.3,
  expected package suffix: 1_3" by implementing shared library
  packaging policy.
* Tue Oct 19 2021 Predrag Ivanović <predivan@mts.rs>
- Update to version 5.5
  * No upstream provided changelog
  * Drop asprintf.patch, merged upstream
  * Add patches to fix build failures caused by clang13 warnings treated as errors
  (https://patch-diff.githubusercontent.com/raw/apple/swift-corelibs-libdispatch/pull/563.patch)
  (https://patch-diff.githubusercontent.com/raw/apple/swift-corelibs-libdispatch/pull/574.patch)
* Thu Apr 15 2021 Predrag Ivanović <predivan@mts.rs>
- Move Block.h to a sub-directory, so it doesn't conflict with
    libobjc-devel.
* Thu Apr  1 2021 Predrag Ivanović <predivan@mts.rs>
-  Add soversion.patch, to set the version to, by upstream default,
    unversioned shared libraries.
-  Don't remove symlinks to libraries in the main package,
    deadbeef can't find versioned libraries at linking time.
-  Add libdispatch-rpmlintrc to silence errors caused by that.
* Wed Mar 31 2021 Predrag Ivanović <predivan@mts.rs>
- Fix build for Factory/Tumbleweed.
    Build acript assumes gcc is used, so passes the gcc ('auto') flag
    for LTO, which clang doesn't recognize. thanks @ismail on IRC for the tip)
- Add llvm-gold to BuildRequires
- Pass '-Wno-unused-command-line-argument' flag only on aarch64
* Thu Mar 25 2021 Predrag Ivanović <predivan@mts.rs>
- Initial packaging, based on Fedora spec file.
